use serenity::{
    async_trait,
    model::gateway::Ready,
    model::{
        application::command::{Command, CommandOptionType},
        prelude::ResumedEvent,
    },
    prelude::{Context, EventHandler},
};

const MAX_ARGS_NUMBER: u32 = 25;

pub struct Handler;

#[async_trait]
impl EventHandler for Handler {
    async fn ready(&self, ctx: Context, ready: Ready) {
        println!("Successfully connected as {}", ready.user.name);

        let _ = Command::create_global_application_command(&ctx.http, |command| {
            command
                .name("tag new")
                .description("Add a new tag")
                .create_option(|option| {
                    option
                        .name("new_tag")
                        .description("The new tag to add")
                        .kind(CommandOptionType::String)
                        .required(true)
                })
        })
        .await;

        let _ = Command::create_global_application_command(&ctx.http, |command| {
            let command = command
                .name("tag bulk_new")
                .description("Add multiples tags");

            for i in 0..MAX_ARGS_NUMBER {
                command.create_option(|option| {
                    option
                        .name("new_tag_{i+1}")
                        .kind(CommandOptionType::String)
                        .required(i == 0)
                });
            }

            command
        })
        .await;

        let _ = Command::create_global_application_command(&ctx.http, |command| {
            command
                .name("tag delete")
                .description("Delete a tag")
                .create_option(|option| {
                    option
                        .name("tag")
                        .kind(CommandOptionType::String)
                        .required(true)
                })
        });
    }

    async fn resume(&self, _: Context, _: ResumedEvent) {
        println!("Successfully reconnected.")
    }
}
